import os
from setuptools import setup, find_packages

VERSION="0.1.0"
PACKAGE = os.path.basename(os.path.dirname(os.path.abspath(__file__)))

# python3 setup.py sdist
# twine upload dist/{PACKAGE}-{VERSION}.tar.gz

setup(
    author='tuweifeng',
    author_email='907391489@qq.com',
    url=f'https://github.com/tuweifeng/{PACKAGE}',

    name=PACKAGE,
    version=VERSION,
    packages=find_packages(),

    description='Django with gRPC、Swagger',
    long_description= open("README.md", "r", encoding='utf-8').read(),  # 项目的描述 读取README.md文件的信息
    long_description_content_type="text/markdown", 

    platforms="any",
    include_package_data=True,

    # 安装过程中，需要安装的静态文件，如配置文件、service文件、图片等
    data_files=[
        # ('', ['conf/*.conf']),
        # ('/usr/lib/systemd/system/', ['bin/*.service']),
    ],

    # 希望被打包的文件
    package_data = {
        #  "目录": [
        #     'template/*/*',
        # ],
    },

    # 不打包的文件
    exclude_package_data = {
        #  "目录": [
        #     'template/*/*',
        # ],
    },

    # 生成终端命令
    entry_points = {
        # 'console_scripts': [
        #     'toolpy = toolpy.main:main',
        # ]
    },

    # 开源许可证
    license='MIT',

    # 分类
    classifiers=[
        # "Development Status :: 1 - Planning",  # 需求版，产品原型，demo
        # "Development Status :: 2 - Pre-Alpha", # 开发版，还在开发功能
        # "Development Status :: 3 - Alpha",  # 测试版，一般为软件项目团队内部测试，不对外公开
        "Development Status :: 4 - Beta", # 测试版，通过内部测试的版本，一般会通过特定方式对外公开测试；
        # "Development Status :: 5 - Production/Stable", # 稳定版，一般指修复发布版出现的BUG后，再发布的正式版本
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        # "Environment :: Web Environment",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Framework :: Django",
        "Framework :: Django :: 3.2",
    ],

    # 自动安装依赖的包
    install_requires=[
        'django>=3.2.9',
        'drf-yasg>=1.20.0',
        'grpcio-tools>=1.44.0',
        'djangogrpcframework>=0.2.1',
        'djangorestframework>=3.12.4'
    ],

    # 这里列出的包，不会自动安装。
    setup_requires=[
        # 'pbr'
    ],

    # 但是这些包通常不会使用到，只有当你深度使用模块时，才会用到，这里需要你手动安装
    extras_require={
        # 'PDF':  ["ReportLab>=1.2", "RXP"],
    },

    # 在执行python3 setup.py test时，可以自动安装这三个库，确保测试的正常运行。
    tests_require=[
        # 'pytest>=3.3.1',
        # 'pytest-cov>=2.5.1',
    ],

    # python 的版本
    python_requires='>=3.6',
)
